# Joystick Plug-in

Das JOYSTICK Plug-in regelt Eingabe von Joystickgeräten, sowie Trackballs und Computerspiel-Gamepads. In dem es das Joystick Modul von Pygame benutzt, erlaubt das JOYSTICK Plug-in den Gebrauch von Tasten, Achsen, Trackballs und Hats. 

## Optionen und Antwortvariablen

Das JOYSTICK Plug-in funktioniert analog zu dem KEYBOARD_RESPONSE Item. Für mehr Informationen, gehen Sie zur Hilfeseite vom KEYBOARD_RESPONSE Item oder besuchen Sie:

- <http://osdoc.cogsci.nl/3.2/manual/response/keyboard/>

## Tastennamen

Abhängig vom Typ des Joysticks oder Gamepads, welches Sie gebrauchen, werden unterschiedlich viele Tasten, Axen, Trackballs und Hats verfügbar sein. Bitte stellen Sie sicher, dass Sie wissen welche Tasten zu welcher Tastennummer gehört (und ebenso für Axen, Hats und Trackballs).

Führ mehr Informationen, gehen Sie zu:

- <http://osdoc.cogsci.nl/3.2/manual/response/joystick/>
